<?php
namespace plugins\file_manager\services;

use plugins\file_manager\library\exceptions;

class DeleteDirectory {

    private $path;

    public function __construct( $path ) {
        $this->path = $path;
    }

    public function perform( $listener ) {
        if ( !is_dir( $this->path ) ) {
            throw new exceptions\FileNotFoundException( sprintf( 'The directory %s does not exist.', $this->path ) );
        }
        if ( !is_writable( $this->path ) ) {
            throw new exceptions\DirectoryNotWritableException( sprintf( 'The directory %s is not writable', $this->path ) );
        }
        if ( !self::deleteTree( $this->path ) ) {
            throw new \RuntimeException( sprintf( 'Could not delete directory %s.', $this->path ) );
        }
    }

    public static function deleteTree( $path ) {
        $files = array_diff( scandir( $path ), ['.', '..'] );
        foreach( $files as $file ) {
            $filename = $path . DS . $file;
            ( is_dir( $filename ) ) ? self::deleteTree( $filename ) : unlink( $filename );
        }
        return rmdir( $path );
    }
}
